@@ -174,7 +174,7 @@ help_cb (GtkWidget  *widget,
 						 GTK_BUTTONS_CLOSE,
 						 _("Could not display help: %s"),
 						 err->message);
-		gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR "quick-lounge-applet.png");
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "quick-lounge-applet");
 		gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (data->quick_lounge->applet)));
 		
 		g_signal_connect (G_OBJECT (dialog), "response",
