@@ -33,6 +33,7 @@
 #include <dirent.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <libgnome/libgnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-handle.h>
@@ -993,15 +994,11 @@ get_unique_desktop_file (const char *base_dir)
 	static int n = 0;
 	
 	while (TRUE) {
-		char     *path;
-		char     *name;
+		char  *path;
+		char  *name;
 
-		name = g_strdup_printf ("QL.%d.%d", getpid (), n++);
-		path = g_strconcat (base_dir,
-				    "/",
-				    name,
-				    ".desktop",
-				    NULL);
+		name = g_strdup_printf ("QL.%d.%d.desktop", getpid (), n++);
+		path = g_build_filename (base_dir, name, NULL);
 		g_free (name);
 
 		if (! g_file_test (path, G_FILE_TEST_EXISTS))
