@@ -24,8 +24,7 @@
 #include <string.h>
 #include <libgnome/libgnome.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-theme.h>
-
+#include <glib/gi18n.h>
 
 GtkWidget *
 _gtk_image_new_from_xpm_data (char * xpm_data[])
@@ -102,88 +101,6 @@ create_button (const char *stock_id,
 	return button;
 }
 
-
-GtkWidget*
-_gtk_message_dialog_new (GtkWindow        *parent,
-			 GtkDialogFlags    flags,
-			 const char       *stock_id,
-			 const char       *message,
-			 const char       *first_button_text,
-			 ...)
-{
-	GtkWidget    *d;
-	GtkWidget    *label;
-	GtkWidget    *image;
-	GtkWidget    *hbox;
-	va_list       args;
-	const gchar  *text;
-	int           response_id;
-	GtkStockItem  item;
-	char         *title;
-
-	if (stock_id == NULL)
-		stock_id = GTK_STOCK_DIALOG_INFO;
-
-	if (gtk_stock_lookup (stock_id, &item))
-		title = item.label;
-	else
-		title = _("Quick Lounge");
-
-	d = gtk_dialog_new_with_buttons (title, parent, flags, NULL);
-	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
-
-	/* Add label and image */
-
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-
-	label = gtk_label_new (NULL);
-	gtk_label_set_markup (GTK_LABEL (label), message);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
-	
-	gtk_box_pack_start (GTK_BOX (hbox), image,
-			    FALSE, FALSE, 0);
-	
-	gtk_box_pack_start (GTK_BOX (hbox), label,
-			    TRUE, TRUE, 0);
-	
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
-			    hbox,
-			    FALSE, FALSE, 0);
-	
-	gtk_widget_show_all (hbox);
-	
-	/* Add buttons */
-
-	if (first_button_text == NULL)
-		return d;
-
-	va_start (args, first_button_text);
-
-	text = first_button_text;
-	response_id = va_arg (args, gint);
-
-	while (text != NULL) {
-		gtk_dialog_add_button (GTK_DIALOG (d), text, response_id);
-
-		text = va_arg (args, gchar*);
-		if (text == NULL)
-			break;
-		response_id = va_arg (args, int);
-	}
-
-	va_end (args);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-
-	return d;
-}
-
-
 char *
 _gtk_request_dialog_run (GtkWindow        *parent,
 			 GtkDialogFlags    flags,
@@ -287,76 +204,6 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 }
 
 
-GtkWidget*
-_gtk_yesno_dialog_new (GtkWindow        *parent,
-		       GtkDialogFlags    flags,
-		       const char       *message,
-		       const char       *no_button_text,
-		       const char       *yes_button_text)
-{
-	GtkWidget    *d;
-	GtkWidget    *label;
-	GtkWidget    *image;
-	GtkWidget    *hbox;
-	GtkWidget    *button;
-	GtkStockItem  item;
-	char         *title;
-	char         *stock_id = GTK_STOCK_DIALOG_QUESTION;
-
-	if (gtk_stock_lookup (stock_id, &item))
-		title = item.label;
-	else
-		title = _("Quick Lounge");
-
-	d = gtk_dialog_new_with_buttons (title, parent, flags, NULL);
-	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
-
-	/* Add label and image */
-
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-
-	label = gtk_label_new (message);	
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	
-	gtk_box_pack_start (GTK_BOX (hbox), image,
-			    FALSE, FALSE, 0);
-	
-	gtk_box_pack_start (GTK_BOX (hbox), label,
-			    TRUE, TRUE, 0);
-	
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
-			    hbox,
-			    FALSE, FALSE, 0);
-	
-	gtk_widget_show_all (hbox);
-
-	/* Add buttons */
-
-	button = create_button (GTK_STOCK_CANCEL, no_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
-				      GTK_RESPONSE_CANCEL);
-
-	/**/
-
-	button = create_button (GTK_STOCK_OK, yes_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d), 
-				      button, 
-				      GTK_RESPONSE_YES);
-
-	/**/
-
-	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-	
-	return d;
-}
-
-
 void
 _gtk_error_dialog_from_gerror_run (GtkWindow        *parent,
 				   GError          **gerror)
@@ -365,12 +212,11 @@ _gtk_error_dialog_from_gerror_run (GtkWindow        *parent,
 	
 	g_return_if_fail (*gerror != NULL);
 	
-	d = _gtk_message_dialog_new (parent,
-				     GTK_DIALOG_MODAL,
-				     GTK_STOCK_DIALOG_ERROR,
-				     (*gerror)->message,
-				     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
-				     NULL);
+	d = gtk_message_dialog_new (parent,
+				    GTK_DIALOG_MODAL,
+				    GTK_MESSAGE_ERROR,
+				    GTK_BUTTONS_OK,
+				    "%s", (*gerror)->message);
 	gtk_dialog_run (GTK_DIALOG (d));
 	gtk_widget_destroy (d);
 	g_clear_error (gerror);
@@ -390,12 +236,11 @@ _gtk_error_dialog_run (GtkWindow        *parent,
 	message = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	d =  _gtk_message_dialog_new (parent,
-				      GTK_DIALOG_MODAL,
-				      GTK_STOCK_DIALOG_ERROR,
-				      message,
-				      GTK_STOCK_OK, GTK_RESPONSE_OK,
-				      NULL);
+	d =  gtk_message_dialog_new (parent,
+				     GTK_DIALOG_MODAL,
+				     GTK_MESSAGE_ERROR,
+				     GTK_BUTTONS_OK,
+				     "%s", message);
 	g_free (message);
 
 	gtk_dialog_run (GTK_DIALOG (d));
@@ -416,12 +261,11 @@ _gtk_info_dialog_run (GtkWindow        *parent,
 	message = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	d =  _gtk_message_dialog_new (parent,
-				      GTK_DIALOG_MODAL,
-				      GTK_STOCK_DIALOG_INFO,
-				      message,
-				      GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
-				      NULL);
+	d =  gtk_message_dialog_new (parent,
+				     GTK_DIALOG_MODAL,
+				     GTK_MESSAGE_INFO,
+				     GTK_BUTTONS_CLOSE,
+				     "%s", message);
 	g_free (message);
 
 	gtk_dialog_run (GTK_DIALOG (d));
@@ -499,10 +343,11 @@ _gtk_label_get_locale_text (GtkLabel *label)
  * Modified by Paolo Bacchilega for the Quick Lounge applet
  */
 static char *
-panel_find_icon (GnomeIconTheme  *icon_theme,
+panel_find_icon (GtkIconTheme    *icon_theme,
                  const char      *icon_name,
                  gint             size)
 {
+	GtkIconInfo *icon_info;
         char *retval;
         char *icon_no_extension;
         char *p;
@@ -536,17 +381,26 @@ panel_find_icon (GnomeIconTheme  *icon_theme,
             *p = 0;
         }
 
-        retval = gnome_icon_theme_lookup_icon (icon_theme, icon_no_extension,
-					       size, NULL, NULL);
+	icon_info = gtk_icon_theme_lookup_icon (icon_theme, 
+						icon_no_extension, 
+					        size, 
+					        0);
 	
         g_free (icon_no_extension);
 
+	if (icon_info) {
+		retval = g_strdup (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+		
+	} else
+		retval = NULL;
+
         return retval;
 }
 
 
 GdkPixbuf *
-create_pixbuf (GnomeIconTheme  *icon_theme,
+create_pixbuf (GtkIconTheme    *icon_theme,
 	       const char      *icon_name,
 	       int              icon_size)
 {
@@ -592,7 +446,7 @@ create_pixbuf (GnomeIconTheme  *icon_theme,
 
 
 GtkWidget *
-create_image (GnomeIconTheme  *icon_theme,
+create_image (GtkIconTheme    *icon_theme,
 	      const char      *icon_path,
 	      int              icon_size)
 {
