@@ -22,6 +22,7 @@
 
 #include <config.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/libgnome.h>
@@ -69,8 +70,6 @@ enum {
 static GtkTargetEntry target_table[] = {
 	{ "text/uri-list", 0, 0 }
 };
-static guint n_targets = sizeof (target_table) / sizeof (target_table[0]);
-
 
 static void
 destroy_prop_dlg_cb (GtkWidget   *widget, 
@@ -94,8 +93,12 @@ properties_verb_cb (BonoboUIComponent *uic,
 				  quick_lounge);
 	}
 
-	if (quick_lounge->prop_dialog != NULL)
+	if (quick_lounge->prop_dialog != NULL) {
+                gtk_window_set_screen (GTK_WINDOW (quick_lounge->prop_dialog),
+                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+
 		gtk_window_present (GTK_WINDOW (quick_lounge->prop_dialog));
+        }
 }
 
 
@@ -129,6 +132,7 @@ about_verb_cb (BonoboUIComponent *uic,
 	       QuickLounge       *quick_lounge,
 	       const gchar       *verbname)
 {
+        static GtkWidget *about_dialog = NULL;
 	GdkPixbuf  *pixbuf = NULL;
         char       *file;
 	const char *authors[] = {
@@ -140,29 +144,43 @@ about_verb_cb (BonoboUIComponent *uic,
 		NULL
 	};
 	const char *translator_credits = _("translator_credits");
-	
+
+        if (about_dialog) {
+                gtk_window_set_screen (GTK_WINDOW (about_dialog),
+                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+                gtk_window_present (GTK_WINDOW (about_dialog));
+                return;
+        }
+
+        about_dialog = gtk_about_dialog_new ();
+
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "quick-lounge-applet.png", TRUE, NULL);
 	if (file != NULL) {
 		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 		g_free(file);
 	}
 
-	gtk_show_about_dialog (NULL,
-			       "name", _("Launchers List"),
-			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 2002-2005 Free Software Foundation, Inc.",
-			       "comments", _("Organize your favorite applications on the Panel"),
-			       "authors", authors,
-			       "documenters", documenters,
-			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			       "logo", pixbuf,
-			       NULL);
+        g_object_set (about_dialog,	
+		      "name", _("Launchers List"),
+	              "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2002-2005 Free Software Foundation, Inc.",
+	              "comments", _("Organize your favorite applications on the Panel"),
+	              "authors", authors,
+	              "documenters", documenters,
+    	              "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+	              "logo", pixbuf,
+	              NULL);
 
 	if (pixbuf)
 		g_object_unref (pixbuf);
+
+	gtk_window_set_wmclass (GTK_WINDOW (about_dialog), "quick-lounge-applet", "Quick-lounge-applet"); 
+        gtk_window_set_screen (GTK_WINDOW (about_dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	g_signal_connect (about_dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &about_dialog);
+	g_signal_connect (about_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_widget_show (about_dialog);
+
 }
-
-
 static const BonoboUIVerb menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("QLProperties",   properties_verb_cb),
 	BONOBO_UI_UNSAFE_VERB ("QLHelp",         help_verb_cb),
@@ -406,8 +424,26 @@ ditem_properties_clicked (GtkWidget *w,
 	GtkWidget *dialog = data;
 
         if (response == GTK_RESPONSE_HELP) {
-		/* FIXME */
+		GError *error = NULL;
+		
+		gnome_help_display_desktop_on_screen (NULL,
+						      "user-guide",
+                                                      "user-guide.xml",
+                                                      "gospanel-52",
+                                                      gtk_window_get_screen (GTK_WINDOW (dialog)),
+                                                      &error);
 
+                if (error) {
+                        GtkWidget *message_dialog;
+                        message_dialog = gtk_message_dialog_new (NULL, 0,
+                                                                 GTK_MESSAGE_ERROR,
+                                                                 GTK_BUTTONS_OK,
+                                                                 _("There was an error displaying help: %s"),
+                                                                 error->message);
+                        g_error_free (error);
+                        gtk_dialog_run (GTK_DIALOG (message_dialog));
+                        gtk_widget_destroy (message_dialog);
+		}
 	} else if (response == REVERT_BUTTON) { 
 		QuickButton      *button;
 		GnomeDItemEdit   *dedit;
@@ -524,7 +560,7 @@ quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 					      GTK_STOCK_HELP,
 					      GTK_RESPONSE_HELP,
 					      NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (widget), GNOME_ICONDIR "quick-lounge-applet.png");
+	gtk_window_set_icon_name (GTK_WINDOW (widget), "quick-lounge-applet");
 	gtk_window_set_screen (GTK_WINDOW (widget), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 
 	dialog = GTK_DIALOG (widget);
@@ -748,7 +784,7 @@ quick_lounge_new_launcher (QuickLounge *quick_lounge,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (widget), GNOME_ICONDIR "quick-lounge-applet.png");
+	gtk_window_set_icon_name (GTK_WINDOW (widget), "quick-lounge-applet");
 	gtk_window_set_screen (GTK_WINDOW (widget), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 	
 	dialog = GTK_DIALOG (widget);
@@ -964,7 +1000,6 @@ static GtkWidget *
 get_button_from_uri (QuickBox   *quick_box,
 		     const char *uri1)
 {
-	GtkBox *box = GTK_BOX (quick_box);
 	GList  *children, *scan;
 
 	children = gtk_container_get_children (GTK_CONTAINER (quick_box));
@@ -1224,7 +1259,6 @@ quick_lounge_load_uri_async (QuickLounge  *quick_lounge,
 {
 	QuickBox     *quick_box = quick_lounge->quick_box;
 	GList        *children, *scan;
-	GtkContainer *container;
 
 	if (quick_lounge->location != uri) {
 		g_free (quick_lounge->location);
@@ -1463,6 +1497,8 @@ quick_lounge_applet_fill (PanelApplet *applet)
 	int          min_cols, max_size;
 	gboolean     icon_size_follows_panel;
 
+	gtk_window_set_default_icon_name ("quick-lounge-applet");
+
 	quick_lounge = g_new0 (QuickLounge, 1);
 
 	quick_lounge->applet = GTK_WIDGET (applet);
@@ -1474,9 +1510,7 @@ quick_lounge_applet_fill (PanelApplet *applet)
 							  g_free, 
 							  NULL);
 
-	quick_lounge->icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (GNOME_ICON_THEME (quick_lounge->icon_theme), TRUE);
-	gnome_icon_theme_append_search_path (quick_lounge->icon_theme, PIXMAPSDIR);
+	quick_lounge->icon_theme = gtk_icon_theme_get_default ();
 
 	/**/
 
@@ -1521,7 +1555,7 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	gtk_drag_dest_set (GTK_WIDGET (quick_lounge->quick_box),
                            GTK_DEST_DEFAULT_ALL,
-                           target_table, n_targets,
+                           target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 	
 	g_signal_connect (G_OBJECT (quick_lounge->quick_box), 
